#!/bin/bash
#
#  initial              Bleifuss2
#  v 0.2     16.06.12   Captain_Beefheart
#  v 0.3     10.07.12   Bleifuss2 add XBMC Home Directory check
#  v 0.3     25.09.12   Bleifuss2 add inputlirc & for lircmap.xml
#Setup Return Codes
#define NO_ERROR				0
#define NO_REMOTE_CON				10
#define CREATE_LIRC_CONF_FILE_ERROR		11
#define CREATE_CFG_FILE_ERROR			12
#define PARAMETER_ERROR				13
#define ERROR_READ_PCHANGER_CONF_FILE		14
#define ERROR_READ_PCHANGER_SH_FILE		15
#define CREATE_LIRCMAP_XML_ERROR		16


##### includes #####
. /usr/lib/vdr/easyvdr-config-loader
. /usr/lib/vdr/functions/easyvdr-functions-lib
. /usr/share/easyvdr/setup/easyvdr-setup-defines
. /usr/share/easyvdr/setup/easyvdr-setup-functions

##### definitionen #####

PCH_DIR="/usr/share/easyvdr/program-changer"                              #PChanger directory
PCH_CONF="/etc/vdr/program-changer/program-changer.conf"                  #Parameter 1: program-changer.conf
RMT_CONF="$CFG_DIR/remote.conf"                                           #Parameter 2: Funktionierende VDR remote.conf
LIRC_MAP="/home/easyvdr/.xbmc/userdata/Lircmap.xml"                       #Parameter 3: Lircmap.xml
LIRC_CONF="/etc/lirc/lircd.conf"                                          #Parameter 4: lircd.conf
PCH_KEY_CONF="/etc/vdr/program-changer/program-changer-keyboard.conf"     #Pfad für Tastatur Belegung
XBMC_HOME="/home/easyvdr/.xbmc"                                           #Pfad für XBMC Home Verzeichnis
XBMC_HOME_USERDATA="/home/easyvdr/.xbmc/userdata"                         #Pfad für XBMC Home/userdaten Verzeichnis
IRTRANS_REM_CONF="/usr/share/irtrans/remotes/irtrans.rem"                 #Pfad für irtrans.rem Datei
TIMEOUT=10                                                                # 10 sec timeout

##### functions  ####

#####

Run_Pch_Setup()
{
CFG_FILES_EXIST="false"; 
[ -f $PCH_CONF ] && CFG_FILES_EXIST="true"


if [[ $CFG_FILES_EXIST == "true" ]]
  then
    if [ ! -d $XBMC_HOME ]; then
     mkdir $XBMC_HOME
      if [ ! -d $XBMC_HOME_USERDATA ]; then
       mkdir $XBMC_HOME_USERDATA
       chown easyvdr:easyvdr $XBMC_HOME_USERDATA
       chmod -R 777 $XBMC_HOME
     fi
    fi
echo $LIRC_HW_CONF

    case $LIRC_HW_CONF in
          input_lirc)
            REMOTE_NAME="-xbmc-remote-name-1 /dev/input/ir-auto_dtc0 -xbmc-remote-name-2 /dev/input/ir-auto_dtc1" ;;
          irtrans_server)
            REMOTE_NAME="-xbmc-remote-name-1 $(grep -q NAME $IRTRANS_REM_CONF | cut -f2 -d"]")" ;;
          *)
            REMOTE_NAME="-xbmc-remote-name-from-lirc-conf "$LIRC_CONF ;;
    esac

    #Testen ob User Konfiguration existiert
    if [ ! -e $PCH_DIR/list-of-programs-user.conf ]; then
     cp $PCH_DIR/list-of-programs-user-conf-template  $PCH_DIR/list-of-programs-user.conf
    fi
    #Datenbank erstellen
    cat $PCH_DIR/list-of-programs-conf-template > $PCH_DIR/list-of-programs.conf
    cat $PCH_DIR/list-of-programs-user.conf >> $PCH_DIR/list-of-programs.conf

    /usr/bin/program_changer_setup -pchanger-conf $PCH_CONF -vdr-remote-conf $RMT_CONF -xbmc-lircmap-xml $LIRC_MAP $REMOTE_NAME
    CNF_SUCCESS=$?
    $PCH_DIR/make-program-changer-script.sh
    start easyvdr-frontend
#echo  CNS  $CNF_SUCCESS
fi

if [[ $CNF_SUCCESS == 0 ]] || [[ $CNF_SUCCESS == 16 ]]
  then 
     SetSysconfig "START_CHANGER" "pch_run"  ; Write_Status "configured"
  else
     SetSysconfig "START_CHANGER" "pch_stop" ; Write_Status "unconfigured"
     Show_Message
fi
}

#####
Write_Status()
{
RC_PCH_STAT=$1
sed -i '/"*program-changer-setup.sh"*/d' $SETUP_STATUS
echo "# `date` program-changer-setup.sh zuletzt ausgefuehrt" >> $SETUP_STATUS
sed -i '/PCH_Setup"*/d' $SETUP_STATUS
echo "PCH_Setup=\"$RC_PCH_STAT\""                            >> $SETUP_STATUS
}

#####
Show_Message()
{
TITLE=" PChanger Fehlermeldung "

case $CNF_SUCCESS in
   1) TEXT1="Fehler1"                                    ;;
   2) TEXT1="Fehler2"                                    ;;
   3) TEXT1="Fehler3"                                    ;;
  15) TEXT1="remote.conf oder lircd.conf nicht gefunden" ;;
   *) TEXT1="unbekannter Fehler"                         ;;
esac

TEXT2=" evtl. auch in fett ! "
TEXT3=" oder in rot  "
TEXT4=" oder auch so "

export DISPLAY=:0
[ -f /usr/bin/zenity ] && Displ_with_Zenity || Displ_with_Dialog
}

#####
Displ_with_Zenity()
{
  {
  i=0
  TIMEOUT_Z=$(( $TIMEOUT * 10 ))
  while (( $i <= $TIMEOUT_Z ))
    do 
      echo $i; sleep 0.1; i=$(( $i + 1 ))
    done ;
  } |zenity --progress \
            --title "$TITLE" \
            --percentage=0 \
            --auto-close \
            --auto-kill \
            --no-cancel \
            --window-icon="$PCH_DIR/pictures/easyvdr-logo.png"\
            --width=530 \
            --height=200 \
            --text \
"$TEXT1\n\
<b>$TEXT2</b> \n\
<span color=\"red\">$TEXT3</span>\n\
<span size=\"xx-large\">$TEXT4</span>\n\n"
}

#####
Displ_with_Dialog()
{
xterm -e bash $PCH_DIR/Dialog_Message "$TITLE" $TIMEOUT "$TEXT1" "$TEXT2" "$TEXT3" "$TEXT4"
}

####################### run ##################################
sleep 10

RunF=1
if (ps -e | grep -q easyvdr-runfron); then
  RunF=0
  svdrpsend remo off
  sleep 1
  stop easyvdr-frontend
  #sleep 0.5
fi

Run_Pch_Setup

if [ $RunF -eq 0 ]; then
   start easyvdr-frontend
   sleep 0.5
   svdrpsend remo on
fi

